@@ -20,7 +20,7 @@
 using namespace PimCommon;
 
 StorageAuthWebView::StorageAuthWebView(QWidget *parent)
-    : QWebView(parent)
+    : QWebEngineView(parent)
 {
 }
 
